### User Settings

“Keep Glyph Names from Imported Files” maintains the names of the glyphs when opening a file in Glyphs instead of forcing the default naming scheme.
This option is useful for workflows that rely on a particular naming scheme, such as exchanging files with other apps.

“Disable Automatic Alignment for Imported Files” disables the automatic positioning for all components when importing a font.
See also Automatic Alignment.

“Disable Localization” keeps the user interface language of Glyphs in English, rather than the localization set in System Settings.
Glyphs needs to be restarted after toggling this option for the change to take effect.

“Use Versions” employs the _Versions_ file saving method.
_Versions_ automatically saves files when closing a document and allows browsing previous versions of the file.
Enable this option to match the behavior of other Mac apps like Pages, or disable it to prevent autosave modifications when opening and closing a file.

When “Send Crash Reports” is checked, Glyphs will send diagnostic information to the Glyphs developers in case the app crashes.
Enter your name and email address so that the developers can get back to you and fix the crash.